<?php

class FormShortcode {

  private static $config;

  static function init() {
    self::$config = array(
      'validation_attr' => 'data-validation',
      'input_container' => array('<p class="full">', '</p>'),
      'dual_container' => array('<p class="dual">', '</p>'),
      'select_container' => array('', ''),
      'radio_container' => array('', ''),
      'checkbox_container' => array('', ''),
      'textarea_container' => array('<p class="full">', '</p>'),
      'submit_container' => array('<p class="text-left">', '</p>')
    );
  }

  static function set_defaults($args) {
    self::$config = wp_parse_args($args, self::$config);
  }
  
  public static function create_id($string) {
    $string = preg_replace('/[^a-z0-9 _-]/i', '', $string); // Strip all unsafe chars
    $string = preg_replace('/[ _-]+/', '_', $string);       // Convert safe symbols to underscore
    $string = preg_replace('/^[0-9]+/', '', $string);       // ID's can't begin with numbers
    $string = strtolower($string);                          // Convert to lower case
    return $string;
  }

  static function form($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'id' => '',
      'class' => 'blocked-form efocus',
      'recipient' => '',
      'from_name' => null,
      'from_email' => null,
      'subject' => null
    );
    
    extract(shortcode_atts($defaults, $atts));
    
    $metadata = array(
      'from_name' => $from_name,
      'from_email' => $from_email,
      'recipient' => $recipient,
      'subject' => $subject,
    );
    
    $html = "\n<form";
    
    if ($id) $html .= sprintf(' id="%s"', $id);
    if ($class) $html .= sprintf(' class="%s"', $class);
    
    $html .= sprintf(' method="post" action="%s">', admin_url('admin-ajax.php?action=sendmsg_submit'));
    $html .= do_shortcode(trim($content));
    
    // Get order
    preg_match_all('/name="([^ ]+)"/', $html, $matches);
    
    $keys = array_unique($matches[1]);
    
    $keys = array_values($keys); // Get keys in real order
    
    $metadata['keys'] = $keys;
    
    $html .= sprintf('  <input type="hidden" name="__metadata__" value="%s" />', $der->encrypt_array($metadata));
    
    $html .= "\n</form>";
    
    if ($id) $html .= "<!-- ${id} -->";
    
    $html = preg_replace('/<br \\/>/', "", $html);
    
    $html = str_replace('###br###', '<br />', $html);
    
    return $html;
    
  }
  
  static function input($atts, $content='', $code='') {
    
    $defaults = array(
      'name' => '',
      'validates' => '',
      'required' => false
    );
    
    extract(shortcode_atts($defaults, $atts));
    
    $template = self::$config['input_container'];
    $label = $name;
    $id = self::create_id($label) . sprintf('[%s]', base64_encode($label));

    if ($required && empty($validates)) $validates = 'class="required" ';
    else if ($validates) $validates = sprintf('class="required" %s="%s" ', self::$config['validation_attr'], $validates);
    
    $html = sprintf('  %s<input type="text" name="%s" placeholder="%s" autocomplete="off" %s/>%s', $template[0], $id, $label, $validates, $template[1]);
    
    return $html;
    
  }
  
  static function dual($atts, $content='', $code='') {
    
    $template = self::$config['dual_container'];
    $input_template = self::$config['input_container'];
    
    $inner = do_shortcode(trim($content));
    
    $inner = str_replace($input_template[0], '', $inner);
    $inner = str_replace($input_template[1], '', $inner);
    
    $html = sprintf("  %s\n   %s\n  %s", $template[0], $inner, $template[1]);
    
    return $html;
    
  }
  
  static function select($atts, $content='', $code='') {
    
    $template = self::$config['select_container'];
    $label = $atts['name'];
    $id = self::create_id($label) . sprintf('[%s]', base64_encode($label));
    
    $html = sprintf('  %s<p><label>%s</label></p><select name="%s">', $template[0], $label, $id);
    
    $options = csv2array($content);
    
    foreach ($options as $opt) {
      // Trim extra characters added by wordpress
      // http://www.php.net/manual/en/function.trim.php#90413
      $opt = trim($opt, "\xc2\xa0");
      $html .= sprintf("\n    " . '<option value="%s">%s</option>', $opt, $opt);
    }
    
    $html .= "\n  </select>" . $template[1];
    
    return $html;
    
  }
  
  static function radio_checkbox_gen($atts, $content='', $type='') {
    
    $template = self::$config["${type}_container"];
    $label = $atts['name'];
    $id = $id_base = self::create_id($label);
    
    $options = csv2array($content);
    $count = count($options);
    
    $html = sprintf("  %s<p><label>%s</label></p>", $template[0], $label);

    if ($type == 'radio') {
      $id .= sprintf('[%s]', base64_encode($label));
    }
    
    for ($i=0; $i < $count; $i++) {
      $option = $options[$i];
      $checked = ($option[0] == '*') ? 'checked="checked"' : '';
      if ($checked) $option = preg_replace('/^\*/', '', $option);
      
      if ($type=='checkbox') {
        $id = sprintf('%s[%s][%s]', $id_base, base64_encode($label), base64_encode($option));
        $html .= sprintf("\n  " . '<p><label><input type="%s" name="%s" %s/> <span>%s</span></label></p>', $type, $id, $checked, $option);
      } else {
        $html .= sprintf("\n  " . '<p><label><input type="%s" name="%s" value="%s" %s/> <span>%s</span></label></p>', $type, $id, $option, $checked, $option);
      }
      
    }
    
    $html .= $template[1];
    
    return $html;
    
  }
  
  static function radio($atts, $content='', $code='') {
    return self::radio_checkbox_gen($atts, $content, 'radio');
  }
  
  static function checkbox($atts, $content='', $code='') {
    return self::radio_checkbox_gen($atts, $content, 'checkbox');
  }
  
  static function textarea($atts, $content='', $code='') {
    
    $defaults = array(
      'name' => '',
      'rows' => 10,
      'cols' => 40
    );
    
    extract(shortcode_atts($defaults, $atts));
    
    $template = self::$config['textarea_container'];
    $label = $name;
    $id = self::create_id($label) . sprintf('[%s]', base64_encode($label)); 
    
    $html = sprintf('  %s<textarea name="%s" rows="%d" cols="%d">%s</textarea>%s', $template[0], $id, $rows, $cols, trim($content), $template[1]);
    
    return $html;
  }
  
  static function submit($atts, $content='', $code='') {

    $template = self::$config["submit_container"];
    $label = $atts['name'];
    
    $html = sprintf('  %s<input type="submit" class="button big" value="%s" />%s' . "\n", $template[0], $label, $template[1]);
    
    return $html;
    
  }

}

?>