<?php

  /* Core Functions */
  
  /* Loads the theme-header.php file on the 'get_header' action. */
  
  add_action('pre_get_posts', 'theme_get_posts');
  
  add_filter('the_content', 'remove_empty_paragraphs', 9999);
  
  function remove_empty_paragraphs($content) {
    $content = str_replace('<p></p>', '', $content);
    $content = preg_replace('/^(\s+)?<\/p>/', '', $content);
    return $content;
  }
  
  /* Responsive video embeds */
  
  if (!class_exists('KplResponsiveVideoEmbeds')) {
    
    add_filter( 'embed_oembed_html', 'modify_embed_output', 9999, 3);
    
    function modify_embed_output( $html, $url, $attr ) {

  	  // Uses code from the RVE Plugin under the GPLv2
  	  // http://wordpress.org/extend/plugins/responsive-video-embeds/

  		// Only run this process for embeds that don't required fixed dimensions
  		$resize = false;
  		$accepted_providers = array(
  			'youtube',
  			'vimeo',
  			'slideshare',
  			'dailymotion',
  			'viddler.com',
  			'hulu.com',
  			'blip.tv',
  			'revision3.com',
  			'funnyordie.com',
  			'wordpress.tv',
  			'scribd.com'
  		);

  		// Check each provider
  		foreach ( $accepted_providers as $provider ) {
  			if ( strstr($url, $provider) ) {
  				$resize = true;
  				break;
  			}
  		}

  		// Not an accepted provider
  		if ( !$resize )
  			return $html;

  		// Pattern for removing width and height attributes
  		$attr_pattern = '/(width|height)="[0-9]*"/i';
  		$whitespace_pattern = '/\s+/';
  		$embed = preg_replace($attr_pattern, "", $html);
  		$embed = preg_replace($whitespace_pattern, ' ', $embed); // Clean-up whitespace
  		$embed = trim($embed);

  		// Add container around the video, use a <p> to avoid conflicts with wpautop()
  		$html = "<p class=\"rve-embed-container\">$embed</p>\n";

  		return $html;
  	}
    
  }
  
  function theme_get_posts($query) { global $der;
    // Allow pagination on homepage
    if (is_home() && !defined('__PAGED__')) {
      // Prevent 404 by overriding paged value
      define('__PAGED__', get_query_var('paged'));
      set_query_var('paged', 1);
    }
  }
  
  function load_theme_header_file() {
    include(TEMPLATEPATH . '/includes/theme-header.php'); 
  }
  
  function theme_breadcrumbs() { global $der;
    
    // Uses code from http://dimox.net/wordpress-breadcrumbs-without-a-plugin/

    $basename = $der->option('breadcrumb_base_name');

    $showOnHome = 1; // 1 - show breadcrumbs on the homepage, 0 - don't show
    $delimiter = ' &nbsp; &raquo; &nbsp; '; // delimiter between crumbs
    $home = ($basename) ? $basename : get_bloginfo('name'); // text for the 'Home' link
    $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
    $before = '<span class="current">'; // tag before the current crumb
    $after = '</span>'; // tag after the current crumb

    $html = array();

    global $post;
    $homeLink = home_url();

    if (is_home() || is_front_page()) {

      if ($showOnHome == 1) $html[] = '<a href="' . $homeLink . '">' . $home . '</a>';

    } else {

      $html[] = '<a href="' . $homeLink . '">' . $home . '</a> ' . $delimiter . ' ';

      if ( is_category() || is_tax('portfolio-category') ) { global $term, $taxonomy;
        
        if (is_tax('portfolio-category')) {
          $cat = get_term_by('slug', $term, $taxonomy);
        } else {
          $cat = get_category(get_query_var('cat'));
        }
        
        if ($cat->parent != 0) {
          $parents = get_term_parents($cat->term_id, $cat->taxonomy, true, ' ' . $delimiter . ' ');
          $parents = explode($delimiter, $parents);
          array_pop($parents);
          array_pop($parents);
          $html[] = implode(' ' . $delimiter . ' ', $parents) . ' ' . $delimiter;
        }
        $html[] = $before . sprintf('%s "', __("Archive by category", "theme")) . esc_html($cat->name) . '"' . $after;

      } elseif ( is_search() ) {
        $html[] = $before . sprintf('%s "', __("Search results for", "theme")) . get_search_query() . '"' . $after;

      } elseif ( is_day() ) {
        $html[] = '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
        $html[] = '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
        $html[] = $before . get_the_time('d') . $after;

      } elseif ( is_month() ) {
        $html[] = '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
        $html[] = $before . get_the_time('F') . $after;

      } elseif ( is_year() ) {
        $html[] = $before . get_the_time('Y') . $after;

      } elseif ( is_single() && !is_attachment() ) {
        
        $post_type = get_post_type();
        
        if ($post_type == 'post' || $post_type == 'portfolio') {
          
          if ($post_type == 'post') {
            $cats = get_the_category(); 
          } else {
            $cats = wp_get_post_terms(get_the_ID(), $post_type . '-category');
          }

          $max = 0;
          $parents = '';
          
          foreach ($cats as $cat) {
            $chain = get_term_parents($cat->term_id, $cat->taxonomy, true, ' ' . $delimiter . ' ');
            $count = substr_count($chain, '<a href=');
            if ($count >= $max) {
              $max = $count;
              $parents = $chain;
            }
          }

          $cats = $parents; // Has the longest chain
          
          // pre($cats);
          
          if ($showCurrent == 0) $cats = preg_replace("#^(.+)\s$delimiter\s$#", "$1", $cats);
          $html[] = $cats;
          if ($showCurrent == 1) $html[] = $before . get_the_title() . $after;
        } else {
          $post_type = get_post_type_object(get_post_type());
          $slug = $post_type->rewrite;
          $html[] = '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a>';
          if ($showCurrent == 1) $html[] = ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
        }
        
      } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
        $post_type = get_post_type_object(get_post_type());
        $html[] = $before . $post_type->labels->singular_name . $after;

      } elseif ( is_attachment() ) {
        if ($showCurrent == 1) $html[] = $before . get_the_title() . $after;
        
      } elseif ( is_page() && !$post->post_parent ) {
        if ($showCurrent == 1) $html[] = $before . get_the_title() . $after;

      } elseif ( is_page() && $post->post_parent ) {
        $parent_id  = $post->post_parent;
        $breadcrumbs = array();
        while ($parent_id) {
          $page = get_page($parent_id);
          $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
          $parent_id  = $page->post_parent;
        }
        $breadcrumbs = array_reverse($breadcrumbs);
        for ($i = 0; $i < count($breadcrumbs); $i++) {
          $html[] = $breadcrumbs[$i];
          if ($i != count($breadcrumbs)-1) $html[] = ' ' . $delimiter . ' ';
        }
        if ($showCurrent == 1) $html[] = ' ' . $delimiter . ' ' . $before . get_the_title() . $after;

      } elseif ( is_tag() ) {
        $html[] = $before . sprintf('%s "', __("Posts tagged", "theme")) . single_tag_title('', false) . '"' . $after;

      } elseif ( is_author() ) {
         global $author;
        $userdata = get_userdata($author);
        $html[] = $before . sprintf('%s by ', __("Articles posted", "theme")) . $userdata->display_name . $after;

      } elseif ( is_404() ) {
        $html[] = $before . __("Error 404", "theme") . $after;
      }

      // if ( get_query_var('paged') ) {
      //   if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) $html[] = ' (';
      //   $html[] = 'Page' . ' ' . get_query_var('paged');
      //   if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) $html[] = ')';
      // }

      return implode("\n", $html);

    }
  }
  
?>