<?php

  /* Layout Components */

  add_shortcode('google_maps', 'google_map_component');
  
  function layout_in_layout_component($atts, $content='', $code) { global $der;
    
    $defaults = array(
      'layout' => null,
      'padding_left' => 0,
      'padding_right' => 0
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    extract($args);
    
    if (empty($layout)) return;

    $layout = base64_decode($layout);
    
    if (!$der->layout_exists($layout)) return;
    
    if ($code == 'layout_in_layout') {
      
      return $der->render_nested_layout($layout, $args);
      
    } else {

      return $der->layout($layout);
      
    }
    
  }

  function refineslide_component($atts, $content='', $code) { global $der;
    
    $defaults = array(
      'gallery' => null,
      'category' => null,
      'portfolio-category' => null,
      'image_limit' => 10,
      'height' => null,
      'hide_on_mobile' => false,
      'transition' => "cubeV",
      'autoPlay' => false,
      'delay' => 5000,
      'transitionDuration' => 5000
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['width'] = $der->layout->column_widths[$args['slots']];
    
    if (empty($args['height'])) {
      // If width not specified, set a default width based on the divine proportion
      $args['height'] = floor($args['width']*(0.618033988));
    }
    
    $args['gallery_images'] = theme_get_gallery_images($args);
    
    if (empty($args['gallery_images'])) return;
    
    if ($code == 'refineslide_full') $args['full_width'] = true;
    
    return $der->render('
{{#full_width}}<section class="block no-padding no-sep-after full-width">
<div class="container sixteen columns">{{/full_width}}
<div class="refineslide component {{columns_class}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}">
<ul class="rs-slider" data-options="transition: {{{transition}}}, autoPlay: {{{autoPlay}}}, delay: {{{delay}}}, transitionDuration: {{{transitionDuration}}}">
{{#gallery_images}}
  <li>
    {{#url}}<a href="{{{url}}}">{{/url}}<img src="{{{image}}}" alt="{{{title}}}" />{{#url}}</a>{{/url}}
    <div class="slider-meta">
      <div class="info{{^description}} no-desc{{/description}}">
        <h3><a{{#url}} href="{{{url}}}"{{/url}}>{{title}}</a></h3>
        <small><a{{#url}} href="{{{url}}}"{{/url}}>{{description}}</a></small>
      </div><!-- .info -->
    </div><!-- .rs-caption -->
  </li>
{{/gallery_images}}
</ul><!-- .rs-slider -->
</div><!-- .refineslide -->
{{#full_width}}
</div><!-- .container -->
</section><!-- .block -->{{/full_width}}', $args);

  }

  function query_posts_component($args) {
    $args['default_query'] = true;
    return blog_posts_component($args);
  }

  function post_content_component($atts) { global $der, $content_width;

    $defaults = array(
      'show_image' => true,
      'show_tags' => true,
      'show_comments' => true,
      'before_image' => '',
      'after_image' => '',
      'before_comments' => '',
      'after_comments' => '',
      'hide_on_mobile' => false,
      'enable_lightbox' => true,
      'show_posts_nav' => true
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    extract($args);
    
    the_post();
    
    $mobile_hide = ($hide_on_mobile) ? 'mobile-hide' : null;
    
    printf('<div class="singular blog-posts component %s">
      <article class="post %s %s">', $columns_class, $mobile_hide, implode(' ', get_post_class()));
    
    ////////////////////// BEFORE IMAGE
    if ($before_image) printf('<div class="added-content before-image no-border-box" style="margin: 0 0 1.5em 0;">%s</div>', $before_image);

    // Get audio embed
    $audio = theme_audio_player();
    
    // Get video embed
    if (empty($audio)) $video = theme_video_embed();
    
    if ($show_image) {

      if (isset($video) && $video) echo $video;
      
      else {
        
        $post_image = $der->post_image();
        
        $post_thumb = ($post_image) ? $der->thumb_src($post_image, $der->layout->column_widths[$slots]) : null;
        
        if ($post_thumb) {
          
          if ($enable_lightbox) {
            printf('<a class="frame lightbox" data-title="%s" data-img="%s" href="%s"><img alt="" src="%s" /></a>', get_the_title(), $post_image, $post_image, $post_thumb);
          } else {
            printf('<a class="frame" href="%s"><img alt="" src="%s" /></a>', get_permalink(), $post_thumb);
          }
          
        }
        
      }

    }
    
    ////////////////////// AFTER IMAGE
    if ($after_image) printf('<div class="added-content after-image no-border-box" style="margin: 1.5em 0 0 0;">%s</div>', $after_image);
    
    // Audio player
    
    if ($audio) echo $audio;
    
    if (isset($post_image) && $post_image) {
      echo '<div class="content clearfix">'."\n";
    } else {
      echo '<div class="content clearfix" style="padding-top: 0;">'."\n";
    }
    
    if (!is_attachment()) the_content();
    
    theme_post_pagination();
    
    if (is_user_logged_in()) {
      echo '<div class="clear"></div>
<p class="capsule" style="margin: 2em 0 0;">';

      if (is_page()) {
        $label = "Edit Page";
      } else if (is_attachment()) {
        $label = "Edit Attachment";
      } else {
        $label = "Edit Post";
      }

      edit_post_link(sprintf("<small>%s &rarr;</small>", $label));
      
      echo '</p>';
    }
    
    echo '</div><!-- content -->'."\n";
    
    if ($show_posts_nav && is_single() && !is_attachment()):
      
      // Determine if we need to show the posts navigation
      $post_left = get_adjacent_post(false, '', true);
      $post_right = get_adjacent_post(false, '', false);
      
      if ($post_left || $post_right) {
      
      ?>
    <div class="posts-nav clearfix">
      <span class="float left text-right"><?php previous_post_link('&laquo; %link'); ?></span>
  		<span class="float right text-left"><?php next_post_link('%link &raquo;'); ?></span>
  	</div><!-- posts-nav -->
      <?php 
      
      }
      
    endif;
      
    ////////////////////// BEFORE COMMENTS
    if ($before_comments) printf('<div class="added-content before-comments no-border-box" style="margin: 3em 0 -1.5em 0;">%s</div>', $before_comments);
    
    $tags = ($show_tags) ? theme_get_tags() : null;
    
    $show_comments = ($show_comments && comments_open());
    
    if ($show_comments || $tags) {
      
      if ($show_comments) {

        $comments = get_comments_number();

        if ($comments == 0) {
          $comments_str = __("No Comments", "theme");
          $no_comments = 'no-comments';
        } else if ($comments == 1) {
          $comments_str = __("One Comment", "theme");
          $no_comments = null;
        } else {
          $comments_str = sprintf(__("%d Comments", "theme"), $comments);
          $no_comments = null;
        }

        printf('<div class="borders comment-count %s clearfix">'."\n", $no_comments);

        printf('<h3 class="comment-heading float-left">%s</h3>', $comments_str);

      } else {

        echo '<div class="borders comment-count clearfix">'."\n";

      }

      if ($show_tags) echo $tags;

      echo '</div><!-- .borders -->'."\n";
      
    }

    if ($show_comments && comments_open()) comments_template();
    
    ////////////////////// AFTER COMMENTS
    if ($after_comments) printf('<div class="added-content after-comments no-border-box" style="margin: 3em 0 0 0;">%s</div>', $after_comments);
    
    echo '</article><!-- .post -->

</div><!-- blog-posts -->';
    
  }

  function pagination_component($atts, $content='', $code='') { global $der;

    $defaults = array();
    $args = wp_parse_args($atts, $defaults);
    $query = $der->last_query;
    $pagination = $der->paginate($der->last_query);

    if (empty($pagination)) return;

    $args['pagination'] = $pagination;

    return $der->render('
<div class="{{{columns_class}}}">
{{{pagination}}}
</div>', $args);

  }

  function blocked_quote_component($atts, $content='', $code='') { global $der;

    $defaults = array(
      'align' => 'center',
      'small' => ($atts['size'] == 'small'),
      'quotes' => ($atts['show_quotes'] == 1),
      'title_align' => 'centered',
      'hide_on_mobile' => false
    );

    $args = wp_parse_args($atts, $defaults);

    $args['content'] = apply_filters('the_excerpt', $content);

    return $der->render('<div class="blocked-quote component {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}"{{#small}} data-small="true"{{/small}} data-align="{{{align}}}"{{#quotes}} data-quotes="true"{{/quotes}}>
  <blockquote>{{{content}}}</blockquote>
</div><!-- .blocked-quote -->', $args);

  }

  function title_content_button_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'title' => '',
      'more_text' => '',
      'link_url' => '',
      'hide_on_mobile' => false,
      'show_link' => true,
      'button_type' => 'button',
      'button_align' => 'text-left'
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['more_text'] = __($args['more_text'], "theme");
    
    $args['content'] = $der->content($content);
    
    if ($args['show_link']) {
      $args['is_button'] = ($args['button_type'] == 'button') ? true : false;
    }
    
    return $der->render('<div class="component {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}} clearfix">
<article class="post"><div class="content">
{{#title}}<h3 class="section-title">{{title}}</h3>{{/title}}
{{{content}}}
{{#show_link}}<div class="{{{button_align}}}">
  <a class="{{#is_button}}button{{/is_button}}{{^is_button}}read-more bold-link{{/is_button}}"{{#link_url}} href="{{{link_url}}}"{{/link_url}}>{{more_text}}</a>
</div>{{/show_link}}
</div></article>
</div><!-- .title-content -->', $args);
    
  }

  function title_content_component($atts, $content='', $code='') {
    
    $atts['show_link'] = false;
    
    $defaults = array(
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    return title_content_button_component($args, $content, $code);
  }

  function quick_shortcode_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'section_title' => null,
      'shortcode' => null,
      'options' => null,
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    extract($args);

    if (empty($content)) {
      if ($shortcode) {
        $code = sprintf('[%s %s /]', $shortcode, $options);
      } else {
        $code = '';
      }
    } else {
      if ($shortcode) {
        $code = sprintf('[%s %s]%s[/%s]', $shortcode, $options, $content, $shortcode);
      } else {
        $code = $content;
      }
    }
    
    $render_args = array(
      'section_title' => $section_title,
      'shortcode' => $shortcode,
      'content' => do_shortcode($code),
      'columns_class' => isset($columns_class) ? $columns_class : null,
      'hide_on_mobile' => $hide_on_mobile
    );
    
    return $der->render('
<div class="{{{columns_class}}} no-child-top-margin component{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}">{{#section_title}}
<h3 class="section-title">{{section_title}}</h3>{{/section_title}}
{{{content}}}

</div><!-- quick-shortcode -->', $render_args);

  }

  function pricing_boxes_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'section_title' => '',
      'columns' => 4,
      'showposts' => 16,
      'category' => null,
      'show_link' => true,
      'more_text' => __("Buy Now", "theme"),
      'split_columns' => false,
      'hide_on_mobile' => false,
      'primary_focus' => 'price',
      'money_symbol' => '$'
    );

    $args = wp_parse_args($atts, $defaults);
    
    $args['more_text'] = __($args['more_text'], "theme");
    
    // pre($args);
    
    $args['is_full_width'] = ($args['slots'] == 16);
    
    $args['focus_on_price'] = ($args['primary_focus'] == 'price');
    
    $args = component_get_posts($args, array(
      'show_image' => false, 
      'clearing' => true,
      'post_type' => 'pricing', 
      'taxonomy' => 'pricing-category',
      'excerpt' => false,
      'content' => true,
      'meta_keys' => array('price', 'method', 'url'),
      'reset_query' => false
    ));

    // pre($args);

    return $der->render('
<div class="pricing-boxes {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}} component ovh{{#is_full_width}}{{#split_columns}} mobile-behavior{{/split_columns}}{{/is_full_width}}"{{#is_full_width}}{{#split_columns}} data-mobile-behavior="{{{split_columns}}}"{{/split_columns}}{{/is_full_width}}>
{{#section_title}}<h3 class="section-title">{{{section_title}}}</h3>{{/section_title}}
{{#posts}}

  <div class="pricing-box {{{columns}}}{{#alpha}} alpha{{/alpha}}{{#omega}} omega{{/omega}} {{{post_class}}}">
    <div class="inner">
      <hgroup>
{{#focus_on_price}}
        <h3 class="small">{{{title}}}</h3>
        <h2 class="big">{{money_symbol}}{{price}} <span>{{method}}</span></h2>
{{/focus_on_price}}
{{^focus_on_price}}
          <h2 class="big thin">{{{title}}}</h2>
          <h3 class="small hilite">{{money_symbol}}{{price}} {{method}}</h3>
{{/focus_on_price}}
      </hgroup>
      <div class="content clearfix">
        {{{content}}}
      </div><!-- .content -->
      <div class="text-center">
        {{#show_link}}<a class="solid-button wide" href="{{{url}}}">{{{more_text}}}</a>{{/show_link}}
      </div>
    </div><!-- .inner -->
  </div><!-- .pricing-box -->
{{#clear}}

  <div class="push-30"></div>
{{/clear}}
{{/posts}}
</div><!-- pricing-boxes -->', $args);
    
  }

  function google_map_component($atts, $content='', $code='') {
    $atts['fullwidth_map'] = false;
    $atts['allow_fullscreen'] = false;
    return google_map_full_component($atts, $content, $code);
  }
  
  function google_map_full_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'latlong' => null,
      'map_type' => 'ROADMAP',
      'zoom' => 16,
      'map_height' => 400,
      'content_title' => '',
      'content_link' => '',
      'content_string' => '',
      'content_tooltip' => '',
      'allow_fullscreen' => true,
      'map_id' => '',
      'hide_on_mobile' => false,
      'fullwidth_map' => true
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    if (! $der->load_maps_api) $der->load_maps_api = true;
    
    $args['content_title'] = esc_html(str_replace('"', '\\"', $args['content_title']));
    $args['content_string'] = apply_filters('the_excerpt', str_replace('"', '\\"', $args['content_string']));
    $args['content_tooltip'] = esc_html(str_replace('"', '\\"', $args['content_tooltip']));
    
    extract($args);
    
    $data = array(
      'latLong' => (string) $latlong,
      'mapType' => $map_type,
      'zoom' => (int) $zoom,
      'contentTitle' => $content_title,
      'contentTitleLink' => $content_link,
      'contentTooltip' => $content_tooltip,
      'allowFullScreen' => (bool) $allow_fullscreen
    );
    
    $json = json_encode($data);
    
    $args['json'] = $json;
    
    return $der->render('
{{#fullwidth_map}}
<section{{#map_id}} id="{{{map_id}}}" {{/map_id}} class="google-map full-width{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}" style="height: {{{map_height}}}px; border: solid #c4c4c4; border-width: 1px 0;">
<span class="map-data">
{{{json}}}
</span><!-- .map-data -->
{{#content_string}}<div class="infobox-content">
{{{content_string}}}
</div>{{/content_string}}
</section><!-- google-map -->
{{/fullwidth_map}}
{{^fullwidth_map}}
<div{{#map_id}} id="{{{map_id}}}" {{/map_id}} class="google-map component {{columns_class}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}" style="height: {{{map_height}}}px; border: solid #c4c4c4; border-width: 1px 0;">
<span class="map-data">
{{{json}}}
</span><!-- .map-data -->
{{#content_string}}<div class="infobox-content">
{{{content_string}}}
</div>{{/content_string}}
</div><!-- google-map -->
{{/fullwidth_map}}', $args);
    
  }
  
  function nivo_slider_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'gallery' => null,
      'category' => null,
      'portfolio-category' => null,
      'image_limit' => 10,
      'height' => null,
      'nivo_effect' => 'fade',
      'slices' => 8,
      'boxCols' => 8,
      'boxRows' => 8,
      'animSpeed' => 500,
      'pauseTime' => 3000,
      'directionNav' => true,
      'directionNavHide' => true,
      'pauseOnHover' => true,
      'manualAdvance' => true,
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    if (empty($args['nivo_options'])) $args['nivo_options'] = sprintf("effect: %s", $args['nivo_effect']);
    else $args['nivo_options'] = sprintf("effect: %s, %s", $args['nivo_effect'], $args['nivo_options']);

    $args['width'] = $der->layout->column_widths[$args['slots']];
    
    if (empty($args['height'])) {
      // If width not specified, set a default width based on the divine proportion
      $args['height'] = floor($args['width']*(0.618033988));
    }
    
    $images = theme_get_gallery_images($args);
    
    if (empty($images)) return;
    
    $nivo_options = array();
    
    $opts = csv2array('effect, slices, boxCols, boxRows, animSpeed, pauseTime, directionNav, directionNavHide, pauseOnHover, manualAdvance');
    
    foreach ($opts as $o) {
      $nivo_options[] = sprintf('%s: {{{%s}}}', $o, $o);
    }
    
    $nivo_options = implode(', ', $nivo_options);
    
    $args['gallery_images'] = $images;
    
    $args['full_width'] = ($code == 'nivo_slider_full');
    
    if (count($images)) {
      $args['first_slide'] = $images[0];
      $args['first_slide_desc'] = $images[0]['description'];
    }
    
    return $der->render('
{{#full_width}}<section class="block no-padding no-sep-after full-width">
<div class="container sixteen columns">{{/full_width}}
<div class="slider slider-nivo {{{columns_class}}} component{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}">
  <div class="images ovh" data-nivo-options="' . $nivo_options . '">
{{#gallery_images}}
  <img class="slide" data-permalink="{{{url}}}" data-title="{{title}}" data-description="{{description}}" src="{{{image}}}" />
{{/gallery_images}}
  </div><!-- .images -->
  <div class="slider-meta mobile-small full-width">
    <div class="info{{^first_slide_desc}} no-desc{{/first_slide_desc}}">
{{#first_slide}}
      <h3><a href="{{{url}}}">{{title}}</a></h3>
      <small><a href="{{{url}}}">{{description}}</a></small>
{{/first_slide}}
    </div><!-- .info -->
    <ul class="controls hfloat clearfix" style="display: block;"></ul>
  </div><!-- .slider-meta -->
</div><!-- .slider -->
{{#full_width}}
</div><!-- .container -->
</section><!-- .block -->{{/full_width}}', $args);
 
  }

  function image_gallery_component($atts, $content='', $code='') { global $der;

    $defaults = array(
      'gallery' => null,
      'category' => null,
      'portfolio-category' => null,
      'image_limit' => 10,
      'title' => '',
      'columns' => 4,
      'height' => null,
      'split_columns' => 0,
      'show_link' => false,
      'more_text' => __("More Images", "theme"),
      'link_url' => '',
      'button_type' => 'button',
      'button_align' => 'text-left',
      'enable_lightbox' => true,
      'hide_on_mobile' => false
    );

    $args = wp_parse_args($atts, $defaults);
    
    $args['more_text'] = __($args['more_text'], "theme");
    
    $args['is_full_width'] = ($args['slots'] == 16);

    $args['width'] = $der->layout->column_widths[$args['columns']];
    
    if (empty($args['height'])) {
      // If width not specified, set a default width based on the divine proportion
      $args['height'] = floor($args['width']*(0.618033988));
    }
    
    // Make sure images are always high def
    
    if ($args['width'] < 420) {
      $args['height'] =  floor(($args['height'] * 420.0) / $args['width']);
      $args['width'] = 420;
    }
    
    $args['image_column_class'] = $der->layout->column_class($args['columns']);

    $images = theme_get_gallery_images($args);
    
    ////////////////////////// [ CLEARING START ]
    
    $clear = $alpha = $omega = $next_alpha = null;
    
    switch ($args['columns']) {
      case 'one-third':
        $every = 3;
        break;
      default:
        $every = $args['slots'] / $args['columns'];
        break;
    }
    
    foreach ($images as $index => $img) {

      $i = $index + 1;

      if ($next_alpha) {
        $alpha = 1;
        $next_alpha = null;
      }

      if ( ($i % $every) === 0 ) {
        $clear = true;
        $omega = true;
        $next_alpha = true;
      }

      if ($i==1) $alpha = 1;

      $images[$index] = array(
        'title' => $img['title'],
        'image' => $img['image'],
        'image_url' => $img['image_src'],
        'description' => $img['description'],
          'url' => $img['url'],
        'alpha' => $alpha,
        'omega' => $omega,
        'clear' => $clear
      );

      $clear = $alpha = $omega = null;

    }
    
    if (count($images) > 0) {
      $last_index = count($images) - 1;
      $images[$last_index]['clear'] = null;
    }
    
    ////////////////////////// [ CLEARING END ]

    $args['gallery_images'] = $images;
    $args['is_button'] = ($args['button_type'] == 'button');
    $args['uniqid'] = uniqid();
    
    return $der->render('<div class="blocked-posts blocked-simple-gallery {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}} component ovh{{#is_full_width}}{{#split_columns}} mobile-behavior{{/split_columns}}{{/is_full_width}}"{{#is_full_width}}{{#split_columns}} data-mobile-behavior="{{{split_columns}}}"{{/split_columns}}{{/is_full_width}}>
{{#title}}<h3 class="section-title">{{title}}</h3>{{/title}}
{{#gallery_images}}
<article class="{{{image_column_class}}}{{#alpha}} alpha{{/alpha}}{{#omega}} omega{{/omega}}">
  <a {{^enable_lightbox}}{{#url}} href="{{url}}"{{/url}} {{/enable_lightbox}} class="frame{{#enable_lightbox}} lightbox{{/enable_lightbox}}" {{#enable_lightbox}}data-title="{{#url}}<a class=\'title\' href=\'{{{url}}}\'>{{/url}}{{#title}}{{title}}{{/title}}{{#description}} &ndash; <small>{{description}}</small>{{/description}}{{#url}}</a>{{/url}}" data-gallery="{{{uniqid}}}" data-img="{{{image_url}}}" {{/enable_lightbox}}href="{{{image}}}"><img alt="" src="{{{image}}}" /></a>
</article><!-- .gallery-item -->
{{#clear}}
<div class="clear push-30"></div>

{{/clear}}
{{/gallery_images}}
{{#show_link}}
<div class="push-20"></div>
<div class="{{{button_align}}}">
  <a class="{{#is_button}}button{{/is_button}}{{^is_button}}read-more bold-link{{/is_button}}"{{#link_url}} href="{{{link_url}}}"{{/link_url}}>{{more_text}}</a>
</div>{{/show_link}}
</div><!-- .blocked-posts -->', $args);

  }

  function portfolio_gallery_component($atts, $content='', $code='') { global $der;
    
    $atts['post_type'] = 'portfolio';
    $atts['taxonomy'] = 'portfolio-category';
    $atts['lightbox'] = true;
    $atts['lightbox_gallery'] = true;
    
    return posts_display_component($atts, $content, $code);
    
  }
  
  function portfolio_slider_gallery_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'category' => '',
      'image_columns' => 8,
      'showposts' => 5,
      'image_height' => null,
      'show_description' => false,
      'show_link' => true,
      'more_text' => __("View Project", "theme"),
      'hide_on_mobile' => false,
      'pagination' => false,
      'metadata_display' => 'description',
      // Nivo Options
      'effect' => 'fade',
      'slices' => 8,
      'boxCols' => 8,
      'boxRows' => 8,
      'animSpeed' => 500,
      'pauseTime' => 3000,
      'directionNav' => true,
      'pauseOnHover' => true,
      'manualAdvance' => true
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['nivo_options'] = sprintf('effect: %s, slices: %d, boxCols: %d, boxRows: %d, animSpeed: %d, pauseTime: %d, pauseOnHover: %d, manualAdvance: %d', 
      $args['effect'], $args['slices'], $args['boxCols'], $args['boxRows'], $args['animSpeed'], $args['pauseTime'], $args['pauseOnHover'], $args['manualAdvance']
    );
    
    $args['more_text'] = __($args['more_text'], "theme");

    $args['image_columns_class'] = $der->layout->column_class($args['image_columns']);
    $args['content_columns_class'] = ($args['image_columns'] >= 16) ? ' sixteen columns' : ' ' . $der->layout->column_class(16 - $args['image_columns']);
    $args['image_width'] = $der->layout->column_widths[$args['image_columns']];

    if (empty($args['image_height'])) {
      $args['image_height'] = floor($args['image_width']*0.618033988);
    }

    $args['is_button'] = ($args['button_type'] == 'button');
    
    $args = component_get_posts($args, array(
      'clearing'=>false, 
      'post_type'=>'portfolio', 
      'taxonomy'=>'portfolio-category',
      'width' => $args['image_width'],
      'height' => $args['image_height'],
      'meta_keys' => array('gallery_images')
    ));
    
    foreach ($args['posts'] as $i => $p) {
      $images = json_decode($p['gallery_images'], true);
      if (is_array($images)) {
        foreach ($images as $j => $data) {
          $images[$j] = sprintf('<img alt="" width="%d" height="%d" src="%s" />', 
            $args['image_width'], 
            $args['image_height'], 
            $der->thumb_src($data['image'], $args['image_width'], $args['image_height']));
        }
        $args['posts'][$i]['gallery_images'] = implode("\n        ", $images);
      }
    }
    
    // pre($args);
    
    return $der->render('
<section class="portfolio-1col block container border-sep{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}">
{{#posts}}
  <article class="post clearfix {{{post_class}}}">
    <div class="slider slider-nivo {{{image_columns_class}}}">
      <div class="images"{{#nivo_options}} data-nivo-options="{{{nivo_options}}}"{{/nivo_options}}>
        {{#image}}<img alt="" width="{{{image_width}}}" height="{{{image_height}}}" src="{{{image}}}" />{{/image}}
        {{{gallery_images}}}
      </div><!-- .images -->
      <div class="slider-meta mobile-small full-width">
        <ul class="controls hfloat clearfix" style="display: block;"></ul>
      </div><!-- .slider-meta -->
    </div><!-- .slider -->
    <aside class="info {{{content_columns_class}}}">
      <h3><a class="title" href="{{{permalink}}}">{{{title}}}</a></h3>
      {{#show_description}}<small>{{{description}}}</small>{{/show_description}}
      {{{excerpt}}}
      {{#show_link}}<div class="more-link-container text-left"><a href="{{{permalink}}}" class="read-more{{#is_button}} button small mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/show_link}}
    </aside><!-- .info -->
  </article><!-- .post -->
{{/posts}}
</section><!-- .portfolio-1col -->
', $args);
    
  }

  function aside_posts_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'section_title',
      'category' => '',
      'showposts' => 16,
      'thumb_width' => 140,
      'thumb_height' => null,
      'show_image' => true,
      'show_description' => false,
      'more_text' => __("Read More", "theme"),
      'button_type' => 'link',
      'button_align' => 'text-left',
      'enable_lightbox' => true,
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['more_text'] = __($args['more_text'], "theme");
    
    $args['width'] = $args['thumb_width'];
    $args['height'] = $args['thumb_height'];
    $args['is_button'] = ($args['button_type'] == 'button');
    
    $args = component_get_posts($args, array('clearing'=>false, 'resize_image'=> false));
    
    $args['uniqid'] = uniqid();
    
    return $der->render('
<div class="blocked-posts-aside {{{columns_class}}} alpha omega{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}} component">
{{#section_title}}<h3 class="section-title">{{section_title}}</h3>{{/section_title}}
{{#posts}}
    <article class="post {{{columns_class}}} clearfix {{{post_class}}}">
      {{#show_image}}<a class="frame float-left{{#enable_lightbox}} lightbox{{/enable_lightbox}}" {{#enable_lightbox}}data-title="<a href=\'{{{permalink}}}\'>{{{title}}}</a>" data-gallery="{{{uniqid}}}" data-img="{{{image_url}}}" {{/enable_lightbox}}href="{{{permalink}}}"><img alt="" width="{{{thumb_width}}}" height="{{{thumb_height}}}" src="{{{image}}}" /></a>{{/show_image}}
      <aside>
        <h3><a class="title" href="{{{permalink}}}">{{{title}}}</a></h3>
        {{#show_description}}<small class="{{{title_align}}}">{{{description}}}</small>{{/show_description}}
        {{{excerpt}}}
        {{#show_link}}<div class="more-link-container {{{button_align}}}"><a href="{{{permalink}}}" class="read-more{{#is_button}} button small mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/show_link}}
      </aside>
    </article><!-- .post -->
{{/posts}}
  </div><!-- .blocked-aside-posts -->
', $args);
    
  }

  function icon_posts_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'category' => '',
      'showposts' => 16,
      'width' => 50,
      'height' => 50,
      'icon_align' => 'left',
      'show_description' => false,
      'title_align' => 'centered',
      'show_link' => false,
      'more_text' => __("Read More", "theme"),
      'button_type' => 'button',
      'button_align' => 'text-left',
      'split_columns' => false,
      'use_timthumb' => false,
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['more_text'] = __($args['more_text'], "theme");
    
    $args = component_get_posts($args, array(
      'show_image' => true, 
      'clearing' => true,
      'post_type' => 'icon-post', 
      'taxonomy' => 'icon-post-category',
      'excerpt' => false,
      'content' => true,
      'permalink' => false,
      'meta_keys' => array('url')
    ));
    
    $args['is_full_width'] = ($args['slots'] == 16);
    $args['is_button'] = ($args['button_type'] == 'button');
    $args['is_centered'] = ($args['icon_align'] == 'centered') ? true : false;
    
    // pre($args);
    
    return $der->render('<div class="{{#is_centered}}blocked-posts{{/is_centered}}{{^is_centered}}blocked-icon-aside-posts{{/is_centered}} {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}} component ovh{{#is_full_width}}{{#split_columns}} mobile-behavior{{/split_columns}}{{/is_full_width}}"{{#is_full_width}}{{#split_columns}} data-mobile-behavior="{{{split_columns}}}"{{/split_columns}}{{/is_full_width}}>
{{#posts}}

  <article class="{{{columns}}}{{#alpha}} alpha{{/alpha}}{{#omega}} omega{{/omega}} {{{post_class}}}">
    {{#is_centered}}<span class="frame bg"><a{{#url}} href="{{{url}}}"{{/url}}><img height="{{{height}}}" src="{{{image}}}" /></a></span>{{/is_centered}}
    <h3 class="{{{title_align}}}">{{#url}}<a class="title" href="{{{url}}}">{{/url}}{{{title}}}{{#url}}</a>{{/url}}</h3>
    {{#show_description}}<small class="{{{title_align}}}">{{{description}}}</small>{{/show_description}}
    {{^is_centered}}<aside class="icon {{{icon_align}}}"><img alt="{{{title}}}" width="{{{width}}}" height="{{{height}}}" src="{{{image}}}"></aside>{{/is_centered}}
    {{{content}}}
    {{#show_link}}{{#url}}<div class="more-link-container {{{button_align}}}"><a href="{{{url}}}" class="read-more{{#is_button}} button small mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/url}}{{/show_link}}
  </article>
{{#clear}}

  <div class="clear push-30"></div>

{{/clear}}
{{/posts}}
</div>', $args);

  }

  function posts_scroller_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'category' => '',
      'showposts' => 10,
      'columns' => 4,
      'thumb_height' => null,
      'show_description' => true,
      'title_align' => 'centered',
      'controls_align' => 'left',
      'enable_lightbox' => true,
      'excerpt' => false,
      'show_link' => false,
      'more_text' => __("Read More", "theme"),
      'button_type' => 'link',
      'button_align' => 'text-left',
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['more_text'] = __($args['more_text'], "theme");
    
    $args['width'] = $der->layout->column_widths[$args['columns']];
    
    if (empty($args['thumb_height'])) {
      $args['height'] = floor($args['width']*0.618033988);
    } else {
      $args['height'] = $args['thumb_height'];
    }
    
    $args = component_get_posts($args, array(
      'excerpt'=> $args['excerpt'], 
      'show_image' => true,
      'clearing' => false
    ));
    
    $args['is_button'] = ($args['button_type'] == 'button');
    $args['uniqid'] = uniqid();
    
    return $der->render("\n".'<div class="blocked-latest-posts {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}} crop component" data-controls="{{{controls_align}}}">
  <div class="scroller clearfix">
{{#posts}}
    <article class="{{{columns}}} {{{post_class}}}">
      <a class="frame{{#enable_lightbox}} lightbox{{/enable_lightbox}}" {{#enable_lightbox}}data-title="<a href=\'{{{permalink}}}\'>{{{title}}}</a>" data-gallery="{{{uniqid}}}" data-img="{{{image_url}}}" {{/enable_lightbox}}href="{{{permalink}}}"><img alt="{{title}}" src="{{{image}}}" /></a>
      <h3 class="{{{title_align}}}"><a class="title" href="{{{permalink}}}">{{{title}}}</a></h3>
      {{#show_description}}<small class="{{{title_align}}}">{{{description}}}</small>{{/show_description}}
      {{#excerpt}}{{{excerpt}}}{{/excerpt}}
      {{#show_link}}<div class="{{{button_align}}}"{{^excerpt}} style="margin-top: 0.8em;"{{/excerpt}}><a href="{{{permalink}}}" class="read-more{{#is_button}} button small mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/show_link}}
    </article><!-- .post -->
{{/posts}}
  </div><!-- .scroller -->
</div><!-- .{{{columns_class}}} -->'."\n", $args);

  }

  function posts_display_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'section_title' => '',
      'category' => '',
      'showposts' => 10,
      'columns' => 4,
      'thumb_height' => null,
      'show_title' => true,
      'more_text' => __("Read More", "theme"),
      'show_image' => true,
      'show_link' => true,
      'excerpt' => true,
      'show_description' => false,
      'title_align' => 'text-left',
      'button_type' => 'button',
      'button_align' => 'text-left',
      'split_columns' => '',
      'enable_lightbox' => true,
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['more_text'] = __($args['more_text'], "theme");
    
    $args['width'] = $der->layout->column_widths[$args['columns']];
    
    if (empty($args['thumb_height'])) {
      $args['height'] = floor($args['width']*0.618033988);
    } else {
      $args['height'] = $args['thumb_height'];
    }
    
    $args = component_get_posts($args, array(
      'clearing' => true,
      'meta_keys' => $args['enable_lightbox'] ? array('multimedia') : null
    ));
    
    $args['is_full_width'] = ($args['slots'] == 16);
    $args['is_button'] = ($args['button_type'] == 'button');
    
    $args['uniqid'] = uniqid();
    
    return $der->render('
<div class="blocked-posts {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}} component ovh{{#is_full_width}}{{#split_columns}} mobile-behavior{{/split_columns}}{{/is_full_width}}"{{#is_full_width}}{{#split_columns}} data-mobile-behavior="{{{split_columns}}}"{{/split_columns}}{{/is_full_width}}>
{{#section_title}}<h3 class="section-title">{{section_title}}</h3>{{/section_title}}
{{#posts}}
<article class="{{{columns}}}{{#alpha}} alpha{{/alpha}}{{#omega}} omega{{/omega}} {{{post_class}}}">
  {{#show_image}}{{#image}}<a class="frame{{#enable_lightbox}} lightbox{{/enable_lightbox}}" {{#enable_lightbox}}data-title="<a href=\'{{{permalink}}}\'>{{{title}}}</a>" data-gallery="{{{uniqid}}}" data-img="{{{image_url}}}" {{/enable_lightbox}}href="{{{permalink}}}"><img alt="{{{title}}}" src="{{{image}}}" /></a>{{/image}}{{/show_image}}
  {{#embed}}{{{embed}}}{{/embed}}
  {{#show_title}}<h3 class="{{{title_align}}}"><a class="title" href="{{{permalink}}}">{{{title}}}</a></h3>{{/show_title}}
  {{#show_description}}<small class="{{{title_align}}}">{{{description}}}</small>{{/show_description}}
  {{#excerpt}}{{{excerpt}}}{{/excerpt}}
  {{#show_link}}<div class="{{{button_align}}}"{{^excerpt}} style="margin-top: 0.8em;"{{/excerpt}}><a href="{{{permalink}}}" class="read-more{{#is_button}} button small mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/show_link}}
</article><!-- .post -->
{{#clear}}

    <div class="clear push-30"></div>

{{/clear}}
{{/posts}}
</div><!-- .blocked-posts -->', $args);
    
  }

  function section_title_component($atts, $content='', $code='') { global $der;
    
    $defaults = array(
      'show_description' => true,
      'metadata_display' => 'description',
      'show_breadcrumb' => true
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    if (is_home()) {
      $args['title'] = get_bloginfo('name');
      $args['description'] = get_bloginfo('description');
    } else if (is_archive()) {
      $args['title'] = wp_title(null, false);
      if (is_author()) {
        $args['description'] = __("Author Archive", "theme");
      } else if (is_tag()) {
        $args['description'] = __("Tag Archive", "theme");
      } else if (is_day() || is_year() || is_month()) {
        $args['description'] = __("Date Archive", "theme");
      } else if (is_category() || taxonomy_exists('portfolio-category')) {
        $args['description'] = __("Category Archive", "theme");
      } else {
        $args['description'] = __("Archive", "theme");
      }
    } else if (is_search()) {
      $found = $GLOBALS['wp_query']->found_posts;
      $args['title'] = get_search_query();
      if ($found == 1) {
        $args['description'] = __("Search results. 1 post found.", "theme");
      } else if ($found == 0) {
        $args['description'] = __("Search results. No posts found.", "theme");
      } else {
        $args['description'] = sprintf(__("Search results. %d posts found.", "theme"), $found);
      }
    } else if (is_404()) {
      $args['title'] = __("Page Not Found", "theme");
      $args['description'] = esc_html(__("The page you're looking for can't be found.", "theme"));
    } else {
      $args['title'] = get_the_title();
      $args['description'] = $der->metadata_display($args['metadata_display']);
    }
    
    if (is_home()) $args['show_breadcrumb'] = false;
    
    if ($args['show_breadcrumb']) {
      $args['breadcrumb'] = theme_breadcrumbs();
    }
    
    return $der->render('
<section id="page-title" class="full-width">
  <div class="container">
    <hgroup class="{{{columns_class}}}">
      <h1>{{{title}}}</h1>
      {{#show_description}}{{#description}}<h2>{{{description}}}</h2>{{/description}}{{/show_description}}
    </hgroup>
  </div><!-- .container -->
</section>
{{#show_breadcrumb}}

<!-- + -->

<section id="breadcrumb" class="block container">
  <p class="sixteen columns">
    {{{breadcrumb}}}
  </p>
</section><!-- breadcrumb -->
{{/show_breadcrumb}}', $args);

  }

  function sidebar_component($atts, $content='') { global $der;
    
    $defaults = array(
      'sidebars' => '',
      'sidebars_override' => '',
      'padding_left' => 0,
      'padding_right' => 0,
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    extract($args);

    $mobile_hide = ($hide_on_mobile) ? ' mobile-hide' : '';
    
    if (empty($sidebars)) $sidebars = $sidebars_override;
    
    $sidebars = csv2array(str_replace('___', ' ', $sidebars)); // de-sanitize
    
    $style = '';

    if ($padding_left) $style .= sprintf('padding-left: %dpx; ', $padding_left);
    if ($padding_right) $style .= sprintf('padding-right: %dpx; ', $padding_right);
    
    if (!empty($style)) $style = sprintf(' style="%s"', trim($style));
    
    printf("\n".'<div class="sidebar component %s%s"%s>', $columns_class, $mobile_hide, $style);
    
    foreach ($sidebars as $sidebar) {
      dynamic_sidebar($sidebar);
    }
    
    echo "\n</div><!-- sidebar -->";
    
  }
  
  function blog_posts_component($atts, $content='') { global $der;
    
    $defaults = array(
      'category' => '',
      'custom_query_string' => null,
      'showposts' => 4,
      'pagination' => false,
      'thumb_width' => null,
      'thumb_height' => 0,
      'show_image' => true,
      'show_description' => true,
      'metadata_display' => 'author-date-cats',
      'post_style' => 'metadata-overlay',
      'show_comments' => true,
      'show_link' => true,
      'more_text' => __("Read More", "theme"),
      'button_type' => 'button',
      'button_align' => 'text-left',
      'hide_on_mobile' => false,
      'video_embed' => true,
      'audio_player' => true,
      'enable_lightbox' => true
    );
    
    $args = wp_parse_args($atts, $defaults);

    $args['more_text'] = __($args['more_text'], "theme");
    
    if ($args['post_style'] == 'thumbnail-aside') {
      // Only override width when using the "Thumbnail Aside" post style
      $args['width'] = $args['thumb_width'];
      $args['height'] = $args['thumb_height']; // Intentional
      if (empty($args['width'])) $args['width'] = floor($der->layout->column_widths[$args['slots']] * 0.34375); // Assume a percentage of the slot width
      if (empty($args['height'])) $args['height'] = $args['width']; // Assume width = height, if not specified
    } else {
      $args['width'] = $der->layout->column_widths[$args['slots']];
      $args['height'] = $args['thumb_height']; // Intentional
    }
    
    $args = component_get_posts($args, array(
      'clearing' => false,
      'excerpt' => true,
      'get_comments_open' => true,
      'custom_query_string' => $args['custom_query_string'],
      'get_comment_count' => ($args['post_style'] == 'thumbnail-aside') ? false : true,
      'get_comment_number' => ($args['post_style'] == 'thumbnail-aside'),
      'audio_player' => $args['audio_player'],
      'video_embed' => $args['video_embed'],
      'reset_query' => ! $args['pagination']   // pagination:true, reset_query:false | pagination:false, reset_query:true
    ));
    
    switch ($args['post_style']) {
      case 'metadata-overlay':
        $args['display_overlay'] = true;
        break;
      case 'metadata-below-image':
        $args['display_below_image'] = true;
        break;
      case 'thumbnail-aside':
        $args['display_thumbnail_aside'] = true;
        break;
    }
    
    if ($args['pagination']) {
      $args['pagination_html'] = $der->paginate($der->last_query);
      wp_reset_query(); // If pagination enabled, make sure query is reset
    }

    $args['is_button'] = ($args['button_type'] == 'button');
    
    // pre($args);
    
    $no_image_template = '<a class="frame" style="display: none;"></a>
      <div class="meta">
        <h3><a class="title" href="{{{permalink}}}">{{{title}}}</a></h3>
        {{#show_description}}<p class="desc">{{{description}}}</p>{{/show_description}}
        {{#show_comments}}{{#comments_open}}<a class="comments mobile-hide" href="{{{permalink}}}#comments"><span>{{{comment_count}}}</span></a>{{/comments_open}}{{/show_comments}}
      </div><!-- .meta -->';
    
    return $der->render('
<div class="blog-posts component {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}">
{{#section_title}}<h3 class="section-title">{{section_title}}</h3>{{/section_title}}
  <div class="border-sep">
{{#posts}}{{#display_overlay}}

  <article class="post {{#image}}{{{post_style}}}{{/image}}{{^image}}metadata-below-image{{/image}} {{{post_class}}}">
    {{#show_image}}{{#image}}<div class="post-img">
      <a class="frame{{#enable_lightbox}} lightbox{{/enable_lightbox}}" {{#enable_lightbox}}data-title="<a href=\'{{{permalink}}}\'>{{{title}}}</a>" data-img="{{{image_url}}}" {{/enable_lightbox}}href="{{{permalink}}}"><img alt="{{{title}}}" src="{{{image}}}" /></a>
      <div class="meta">
        <h3><a href="{{{permalink}}}">{{{title}}}</a></h3>
        {{#show_description}}<p>{{{description}}}</p>{{/show_description}}
        {{#show_comments}}{{#comments_open}}<a class="comments mobile-hide" href="{{{permalink}}}#comments"><span>{{{comment_count}}}</span></a>{{/comments_open}}{{/show_comments}}
      </div><!-- .meta -->
    </div><!-- .post-img -->
    {{#embed}}{{{embed}}}{{/embed}}
    {{/image}}{{^image}}
    {{#embed}}{{{embed}}}{{/embed}}
' . $no_image_template . '
    {{/image}}{{/show_image}}{{^show_image}}
    {{#embed}}{{{embed}}}{{/embed}}
' . $no_image_template . '
    {{/show_image}}
    <div class="content clearfix">
      {{{excerpt}}}
      {{#show_link}}<div class="more-link-container {{{button_align}}}"><a href="{{{permalink}}}" class="read-more{{#is_button}} button mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/show_link}}
    </div><!-- .content -->
  </article><!-- .post -->
{{/display_overlay}}{{#display_below_image}}

<article class="post {{{post_style}}} {{{post_class}}}">
  {{#show_image}}{{#image}}<a class="frame{{#enable_lightbox}} lightbox{{/enable_lightbox}}" {{#enable_lightbox}}data-title="<a href=\'{{{permalink}}}\'>{{{title}}}</a>" data-img="{{{image_url}}}" {{/enable_lightbox}}href="{{{permalink}}}"><img alt="" src="{{{image}}}" /></a>{{/image}}{{^image}}
  <a class="frame" style="display: none;"></a>
  {{/image}}{{/show_image}}{{^show_image}}
  <a class="frame" style="display: none;"></a>
  {{/show_image}}
  {{#embed}}{{{embed}}}{{/embed}}
  <div class="meta">
    <h3><a class="title" href="{{{permalink}}}">{{{title}}}</a></h3>
    {{#show_description}}<p>{{{description}}}</p>{{/show_description}}
    {{#show_comments}}{{#comments_open}}<a class="comments mobile-hide" href="{{{permalink}}}#comments"><span>{{{comment_count}}}</span></a>{{/comments_open}}{{/show_comments}}
  </div><!-- .meta -->
  <div class="content clearfix">
    {{{excerpt}}}
    {{#show_link}}<div class="more-link-container {{{button_align}}}"><a href="{{{permalink}}}" class="read-more{{#is_button}} button mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/show_link}}
  </div><!-- .content -->
</article><!-- .post -->
{{/display_below_image}}{{#display_thumbnail_aside}}

  <article class="post {{{post_style}}} alt clearfix {{{post_class}}}">
      {{#show_image}}{{#image}}<div class="post-img float-left" style="width: {{{width}}}px;" >
        <a class="frame{{#enable_lightbox}} lightbox{{/enable_lightbox}}" {{#enable_lightbox}}data-img="{{{image_url}}}" {{/enable_lightbox}}data-title="<a href=\'{{{permalink}}}\'>{{{title}}}</a>" href="{{{permalink}}}"><img alt="" width="{{{width}}}" height="{{{height}}}" src="{{{image}}}" /></a>
        {{#embed}}{{{embed}}}{{/embed}}
      </div><!-- .post-img.alt -->
      {{/image}}{{^image}}
      <div class="post-img" style="display: none;" ></div>
      {{#embed}}{{{embed}}}{{/embed}}
      {{/image}}{{/show_image}}{{^show_image}}
      <div class="post-img" style="display: none;" ></div>
      {{/show_image}}{{^show_image}}
      {{#embed}}{{{embed}}}{{/embed}}
      {{/show_image}}
      <aside class="ovh clearfix">
        <div class="meta">
          <h3><a class="title" href="{{{permalink}}}">{{{title}}}</a></h3>
          {{#show_description}}<p class="desc">{{{description}}}</p>{{/show_description}}
          {{#show_comments}}{{#comments_open}}<p class="comments capsule"><a href="{{{permalink}}}#comments">{{{comment_number}}}</a></p>{{/comments_open}}{{/show_comments}}
        </div><!-- .meta -->
        {{{excerpt}}}
        {{#show_link}}<div class="more-link-container {{{button_align}}}"><a href="{{{permalink}}}" class="read-more{{#is_button}} button mobile-small{{/is_button}}{{^is_button}} bold-link{{/is_button}}">{{{more_text}}}</a></div>{{/show_link}}
      </aside>
  </article><!-- .post -->
{{/display_thumbnail_aside}}{{/posts}}

{{#pagination}}{{{pagination_html}}}{{/pagination}}

  </div><!-- .border-sep -->
</div><!-- blog-posts -->', $args);
    
  }
  
  function staff_display_component($atts, $content='') { global $der;
    
    $defaults = array(
      'section_title' => '',
      'category' => '',
      'showposts' => 16,
      'thumb_width' => 140,
      'thumb_height' => 140,
      'show_image' => true,
      'show_description' => true,
      'hide_on_mobile' => false
    );
    
    $args = wp_parse_args($atts, $defaults);
    
    $args['width'] = $args['thumb_width'];
    $args['height'] = $args['thumb_height'];
    
    $args = component_get_posts($args, array(
      'post_type' => 'person',
      'taxonomy' => 'person-category',
      'excerpt' => false,
      'content' => true,
      'clearing'=>false,
      'permalink' => false,
      'resize_image' => false,
      'meta_keys' => array('url')
    ));

    return $der->render('
<div class="vcard-items component {{{columns_class}}}{{#hide_on_mobile}} mobile-hide{{/hide_on_mobile}}">
{{#section_title}}<h3 class="section-title">{{section_title}}</h3>{{/section_title}}
{{#posts}}

  <div class="vcard-item clearfix {{{post_class}}}">
    {{#show_image}}<div class="photo-frame float-left">
      <a><img alt="{{{title}}}" width="{{{width}}}" height="{{{height}}}" src="{{{image}}}" /></a>
    </div><!-- photo-frame -->{{/show_image}}
    <aside>
      <h3 class="title">{{#url}}<a href="{{{url}}}">{{{title}}}</a>{{/url}}{{^url}}{{{title}}}{{/url}}</h3>
      {{#show_description}}<span class="occupation">{{{description}}}</span>{{/show_description}}
      {{{content}}}
    </aside>
  </div><!-- .vcard-item -->
{{/posts}}

</div><!-- .vcard-items -->', $args);
    
  }

?>