<?php

  /* Theme Functions */
  
  global $der, $theme_typography;
  
  // Set theme typography
  $theme_typography = $der->option_bool('webfonts_enabled')
  ? $der->options('base_font_size, webfont, webfont_subsets, webfont_variants, headings_font, headings_font_subsets, headings_font_variants')
  : null;
  
  // Add typography styles
  if ($theme_typography) add_action('wp_print_styles', 'theme_typography_styles');
  
  // Image Caption shortcode
  add_filter('img_caption_shortcode', 'theme_caption_shortcode', 10, 3);
  // add_filter('comments_open', 'comments_open_override');
  
  // Add typography filter
  add_filter('theme_custom_css', 'theme_typography', 10, 1);
  
  // Add generator filter
  add_filter('get_the_generator_xhtml', 'theme_generator', 10, 1);
  
  // Excerpt filters
  add_filter('excerpt_length', 'theme_excerpt_length');
  add_filter('excerpt_more', 'theme_excerpt_more');
  
  // Layout components
  require(TEMPLATEPATH . '/includes/layout/components.php');
  
  // Layout defaults
  require(TEMPLATEPATH . '/includes/layout/default-components.php');
  
  // Load shortcodes
  $der->load_shortcodes('form, default-slider, standalone, columns');
  
  // Audio File Regex
  define('AUDIO_FILE_REGEX', '/\.(mp3|wav|ogg|mp4)$/i');
  
  //////////////////////////// FUNCTIONS
  
  function theme_asset_path($context) { global $der;
    $minified = $der->option('asset_mode', 'minified') == 'minified';
    if ($context == 'css') {
      return ($minified) ? THEME_STYLESHEET_SOURCE : preg_replace('/\.min\.css$/', '.css', THEME_STYLESHEET_SOURCE);
    } else if ($context == 'js') {
      return ($minified) ? THEME_JAVASCRIPT_SOURCE : preg_replace('/\.min\.js$/', '.js', THEME_JAVASCRIPT_SOURCE);
    }
  }
  
  function theme_generator($gen) { global $der;
    $t = $der->theme_data;
    return $gen . sprintf('<!-- %s %s -->', $t->get('Name'), $t->get('Version'));
  }
  
  function theme_typography_styles() { global $theme_typography;
    
    extract($theme_typography);
    
    $load = array();
    
    // Merge subsets & variants if same fonts chosen
    if ($headings_font == $webfont) {
      if ($headings_font_subsets && $webfont_subsets) $webfont_subsets = array_merge($webfont_subsets, $headings_font_subsets);
      if ($headings_font_variants && $webfont_variants) $webfont_variants = array_merge($webfont_variants, $headings_font_variants);
      $load[$webfont] = webfont_stylesheet_url($webfont, $webfont_subsets, $webfont_variants);
    } else {
      $load[$webfont] = webfont_stylesheet_url($webfont, $webfont_subsets, $webfont_variants);
      $load[$headings_font] = webfont_stylesheet_url($headings_font, $headings_font_subsets, $headings_font_variants);
    }
    
    $replace = '/' . '[^a-z0-9]+/i'; // TextMate has problems with this regex, go figure...
    
    foreach ($load as $font => $url) {
      $id = 'gwf-' . strtolower(preg_replace($replace, '-', $font));
      printf("<link rel='stylesheet' id='%s'  href='%s' type='text/css' media='all' />\n", $id, $url);
    }

  }
  
  function theme_typography($css) { global $der, $theme_typography;
    
    $out = '';

    if ($theme_typography) {
      
      extract($theme_typography);
      
      $out = sprintf('body { font-size: %dpx; }', $base_font_size);
      
      if ($headings_font != $webfont) {
        $out .= sprintf("\n".'body, #header ul.navigation > li > a { font-family: "%s", serif; }
h1, h2, h3, h4, h5, h6, ul.navigation > li > a { font-family: "%s",serif !important; }', $webfont, $headings_font);
      } else {
        $out .= sprintf("\n".'body, h1, h2, h3, h4, h5, h6, #header ul.navigation > li > a { font-family: "%s",serif !important; }', $webfont);
      }
        
    }
    
    if (!empty($css)) $out .= "\n";
    
    return $out . $css;
    
  }
  
  function webfont_stylesheet_url($font, $subsets=array(), $variants=array()) {
    
    // <link href='http://fonts.googleapis.com/css?family=Open+Sans:800italic,400,800&subset=latin,greek-ext' rel='stylesheet' type='text/css'>
    
    $link = "http://fonts.googleapis.com/css?family=" . preg_replace('/\s+/', '+', $font);

    // Add variants
    if (!empty($variants)) {

      $arr = array();

      foreach (array_keys($variants) as $key) {
        if (!is_int($key)) $arr[] = preg_replace('/^_/', '', $key);
      }

      $link .= ':' . implode(',', $arr);
      
    }
    
    // Add subsets
    if (!empty($subsets)) {
      
      $arr = array();
      
      foreach (array_keys($subsets) as $key) {
        if (!is_int($key)) $arr[] = preg_replace('/^_/', '', $key);
      }
      
      $link .= '&amp;subset=' . implode(',', $arr);
        
    }
    
    return $link;
    
  }

  function theme_custom_css() { global $der;
    
    $css = $der->option('custom_css');
    
    if (empty($css)) $css = '';
    
    $css = apply_filters('theme_custom_css', $css);
    
    // Replace ascii char 160 with ascii char 32
    $css = str_replace(' ', ' ', $css);
    
    if (!empty($css)) {
     
      printf("\n\n".'<!-- Custom CSS -->

<style type="text/css">
%s
</style>'."\n", $css);
      
    }
    
  }
  
  function theme_custom_javascript() { global $der;
    
    $js = $der->option('custom_javascript');
    
    if (!empty($js)) {
      
      printf('<!-- Custom JavaScript -->
<script type="text/javascript">
(function($) { $(document).ready(function() {
%s
}); })(jQuery);
</script>'."\n", $js);
      
    }
    
  }
  
  function theme_get_gallery_images($args) { global $der; 
    
    $out = array();

    $limit = $args['image_limit'];
    
    if (isset($args['gallery']) && $args['gallery']) {
      
      ////////////////////// GALLERY POSTS
      
      $images = json_decode(get_post_meta($args['gallery'], $der->key('gallery_images'), true), true);

      if (is_array($images) && !empty($images)) {
        
        $images = array_slice($images, 0, $limit);
        
        foreach ($images as $i => $img) {
          $image = $img['image'];
          $images[$i]['image'] = ($image) ? $der->thumb_src($image, $args['width'], $args['height']) : null;
          $images[$i]['image_src'] = ($image) ? $image : null;
        }
        
        $limit -= count($images);

        $out = array_merge($out, $images);
        
        if ($limit == 0) return $out;
        
      }

    }
    
    if (isset($args['portfolio-category']) && is_array($args['portfolio-category']) && !empty($args['portfolio-category'])) {
      
      ////////////////////// PORTFOLIO POSTS
      
      $cats = implode(',', $args['portfolio-category']);
      $query = sprintf('post_type=portfolio&portfolio-category=%s&showposts=%d', $cats, $limit);
      $posts = query_posts($query); 
      
      while (have_posts()) { the_post(); // title, description, image, url
        
        $post_image = $der->post_image();
        
        $out[] = array(
          'title' => get_the_title(),
          'description' => $der->postmeta('description'),
          'image' => ($post_image) ? $der->thumb_src($post_image, $args['width'], $args['height']) : null,
          'image_src' => ($post_image) ? $post_image : null,
          'url' => get_permalink()
        );
        
      }
      
      wp_reset_query();
      
      $limit -= count($posts);
      
      if ($limit == 0) return $out;
      
    }

    if (isset($args['category']) && is_array($args['category']) && !empty($args['category'])) {
      
      $cats = implode(',', $args['category']);
      $query = sprintf('post_type=post&category_name=%s&showposts=%d', $cats, $limit);
      $posts = query_posts($query);
      
      while (have_posts()) { the_post();
        
        $post_image = $der->post_image();
        
        $out[] = array(
          'title' => get_the_title(),
          'description' => $der->postmeta('description'),
          'image' => ($post_image) ? $der->thumb_src($post_image, $args['width'], $args['height']) : null,
          'image_src' => ($post_image) ? $post_image : null,
          'url' => get_permalink()
        );
        
      }
      
      wp_reset_query();
      
      $limit -= count($posts);
      
      if ($limit == 0) return $out;
      
    }
    
    if (is_array($args['extra-sources'])) {
      
      ////////////////////// PORTFOLIO GALLERY
      
      if (is_single() && get_post_type() == 'portfolio' && in_array('portfolio-gallery', $args['extra-sources'])) {
        
        $images = json_decode($der->postmeta('gallery_images'), true);
        
        if (is_array($images) && !empty($images)) {
          
          $post_image = $der->post_image();

          if ($post_image) {
            // Append post image to gallery images
            $images = array_merge(array(
              array(
                'title' => null,
                'description' => null,
                'image' => $post_image,
                'url' => null
              )
            ), $images);
          }
          
          $images = array_slice($images, 0, $limit);
          
          foreach ($images as $i => $img) {
            $image = $img['image'];
            $images[$i]['image'] = ($image) ? $der->thumb_src($image, $args['width'], $args['height']) : null;
            $images[$i]['image_src'] = ($image) ? $image : null;
          }

          $limit -= count($images);

          $out = array_merge($out, $images);

          if ($limit == 0) return $out;
          
        }
        
      }
      
    }
    
    return $out;

  }

  function component_get_posts($args, $options=array()) { global $der;

    $options = wp_parse_args($options, array(
      'default_query' => false,
      'post_type' => 'post',
      'taxonomy' => 'category_name',
      'custom_query_string' => null,
      'clearing' => true,
      'reset_query' => true,
      'excerpt' => true,
      'content' => false,
      'no_shortcodes' => false,
      'content_without_shortcodes' => false,
      'show_image' => true,
      'show_description' => true,
      'permalink' => true,
      'use_timthumb' => true,
      'post_class' => true,
      'pagination' => false,
      'meta_keys' => null,
      'metadata_display' => 'description',
      'resize_image' => true,
      'get_comments_open' => false,
      'get_comment_count' => false,
      'get_comment_number' => false,
      'audio_player' => false,
      'video_embed' => false
    ));
    
    extract($options);
    
    if ( isset($args['columns']) && $args['columns'] ) {
      $args['columns_src'] = $args['columns'];
      $args['columns'] = $der->layout->column_class($args['columns']);
    }
    
    extract($args);
    
    // Make sure images are always high def
    
    if ($show_image && $resize_image && $width < 420 && $height > 0) {
      $height =  floor(($height * 420.0) / $width);
      $width = 420;
    }
    
    // Pagination
    
    $paged = defined('__PAGED__') ? __PAGED__ : get_query_var('paged');
    
    $pagination = ($pagination) ? ($paged ? $paged : 1) : 1;
    
    if ($default_query == false) {
      if ($custom_query_string) {
        $query = $custom_query_string;
      } else {
        if (is_array($category)) $category = implode(',', $category);
        $query = sprintf('post_type=%s&%s=%s&showposts=%d&paged=%d', $post_type, $taxonomy, $category, $showposts, $pagination);
      }
      query_posts($query);
    }
    
    $posts = array();
    
    // Clearing vars
    
    if ($clearing) {
      
      $i=1; 
      $clear = $alpha = $omega = $next_alpha = null;
      
      switch ($columns_src) {
        case 'one-third':
          $every = 3;
          break;
        default:
          $every = $slots / $columns_src;
      }
      
    }
    
    while (have_posts()) { the_post();
      
      $p = get_post(get_the_ID());
      
      if ($clearing) {
        
        if ($next_alpha) {
          $alpha = 1;
          $next_alpha = null;
        }

        if ( ($i % $every) === 0 ) {
          $clear = true;
          $omega = true;
          $next_alpha = true;
        }

        if ($i==1) $alpha = 1;
        
      }
      
      $arr = array(
        'title' => get_the_title(),
      );
      
      if ($permalink) $arr['permalink'] = get_permalink();
      
      $media = $der->postmeta('multimedia');
      
      if ($media && $audio_player) $arr['embed'] = theme_audio_player(); // Should go before video
      
      if ($show_image) {
        
        if ($media && empty($arr['embed']) && $video_embed) { // If there's audio, there can't be video since they use the same key

          $video = theme_video_embed();
          
          if ($video) {
            // If there's video, image should not be set
            $arr['embed'] = $video;
            $arr['image'] = null;
          }
          
        }
        
        // Assign image only if video is not set. Make sure either one is set, not both
        if (empty($video)) {
          $imgurl = $der->post_image();
          $arr['image'] = $imgurl ? (($use_timthumb) ? $der->thumb_src($imgurl, $width, $height, $der->postmeta(THUMB_CROP_META)) : $imgurl) : null;
          $arr['image_url'] = ($media && !preg_match(AUDIO_FILE_REGEX, $media)) ? $media : $imgurl;
        }
        
        // Reset $video for next loop
        $video = null;
        
      }
      
      if ($show_description) $arr['description'] = $der->metadata_display($metadata_display);
      if ($post_class) $arr['post_class'] = implode(' ', get_post_class());
      if ($excerpt) $arr['excerpt'] = $der->get_excerpt();
      if ($content) $arr['content'] = $der->content($p->post_content, $no_shortcodes);
      if ($get_comments_open) $arr['comments_open'] = comments_open();
      if ($get_comment_count) $arr['comment_count'] = ( $arr['comments_open'] ? true : comments_open() ) ? get_comments_number() : null;
      
      if ($get_comment_number) {
        $count = (isset($args['comment_count']) && is_int($args['comment_count'])) ? $args['comment_count'] : get_comments_number();
        if ( ($arr['comments_open']) ? true : comments_open() ) { // Only set if comments open
          if ($count == 0) $arr['comment_number'] = "No Comments";
          else if ($count > 1) $arr['comment_number'] = sprintf('%d Comments', $count);
          else $arr['comment_number'] = "1 Comment";
        }
      }
      
      if (isset($alpha) && $alpha) $arr['alpha'] = $alpha;
      if (isset($omega) && $omega) $arr['omega'] = $omega;
      if (isset($clear) && $clear) $arr['clear'] = $clear;
        
      if (is_array($meta_keys)) {
        foreach ($meta_keys as $key) {
          $arr[$key] = $der->postmeta($key);
        }
      }
      
      $posts[] = $arr;
      
      if ($clearing) {
        $i++; 
        $clear = $alpha = $omega = null;
      }

    }
    
    if ($clearing && count($posts) > 0) {
      $last_index = count($posts) - 1;
      $posts[$last_index]['clear'] = null;
    }
    
    $args['posts'] = $posts;
    
    if ($pagination) {
      // Set last query, for pagination
      $der->last_query = $GLOBALS['wp_query'];
    }
    
    if ($reset_query) wp_reset_query();
    
    return $args;

  }
  
  function theme_video_embed() { global $der;
    $multimedia = $der->postmeta('multimedia');
    if ($multimedia && !preg_match(AUDIO_FILE_REGEX, $multimedia)) {
      $out = apply_filters('the_content', $multimedia);
      if ($out == '<p>' . $multimedia . '</p>') {
        // Nothing to embed
        return null;
      } else {
        // Oembed successfully generated
        return $out;
      }
    } else {
      return null;
    }
  }
  
  function theme_audio_player() { global $der;
    $multimedia = $der->postmeta('multimedia');
    if ($multimedia && preg_match(AUDIO_FILE_REGEX, $multimedia)) {
      return sprintf("\n".'<div class="multimedia media-type-audio"><audio src="%s"></audio></div><!-- multimedia -->'."\n", $multimedia);
    } else {
      return null;
    }
  }
  
  function comments_open_override($value) {
    // Force comments enabled for portfolio posts
    $post_type = get_post_type();
    return ($post_type == 'portfolio') ? true : $value;
  }
  
  function theme_get_tags() {
    $tags = get_the_tag_list(null, "\n", null);
    $html = '';
    if ($tags) {
      $html.= '<ul class="tags-list hfloat float-right">
<li>Tagged:</li>'."\n";

      $tags = preg_replace('/<a/', '<li><a', $tags);
      $tags = preg_replace('/<\/a>/', '</a></li>', $tags);

      $html .= $tags;

      $html .= "\n".'</ul><!-- .tags -->'."\n";
    }
    return $html;
  }
  
  function theme_post_pagination() {
    
    $post_pages = wp_link_pages(array(
      'before' => '<br/><ul class="pagination post-pagination">
<li class="label">Pages: </li>'."\n",
      'after' => '</ul><!-- .pagination -->',
      'link_before' => '',
      'link_after' => '',
      'pagelink' => '%',
      'echo' => false
    ));
    
    $post_pages = str_replace('<a', '<li class="page"><a', $post_pages);
    $post_pages = str_replace('</a>', '</a></li>'."\n", $post_pages);
    $post_pages = preg_replace('/\s+(\d+)(\s+)?/', "\n".'<li class="page active">$1</li>'."\n", $post_pages);
    
    echo $post_pages;
    
  }
  
  function twentyeleven_comment( $comment, $args, $depth ) {
    
    // Uses code from the TwentyElevent theme under the GPL.
    
  	$GLOBALS['comment'] = $comment;
  	
  	switch ( $comment->comment_type ) :
  		case 'pingback' :
  		case 'trackback' :
  	?>
  	<li class="post pingback">
  		<p><?php __('Pingback', "theme"); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('Edit', "theme"), '<span class="edit-link">', '</span>' ); ?></p>
  	<?php
  			break;
  		default :
  	?>
  	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
  		<article id="comment-<?php comment_ID(); ?>" class="comment">
  			<footer class="comment-meta">
  				<div class="comment-author vcard">
  					<?php
  						$avatar_size = 52;
  						if ( '0' != $comment->comment_parent )
  							$avatar_size = 52;

  						echo get_avatar( $comment, $avatar_size );

  						printf('%1$s on %2$s <span class="says">said:</span>',
  							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
  							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
  								esc_url( get_comment_link( $comment->comment_ID ) ),
  								get_comment_time('c'),
  							  // translators: 1: date, 2: time
  								sprintf('%1$s at %2$s', get_comment_date(), get_comment_time() )
  							)
  						);
  					?>
  					<?php edit_comment_link("Edit", '<span class="edit-link">', '</span>' ); ?>
  				</div><!-- .comment-author .vcard -->

  			</footer>

  			<div class="comment-content"><?php

  				if ( $comment->comment_approved == '0' ) printf('<em class="comment-awaiting-moderation">&mdash; %s &mdash;</em>', 'Your comment is awaiting moderation');

  				comment_text();

  			?></div>

  			<div class="reply">
  				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => 'Reply', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
  			</div><!-- .reply -->
  		</article><!-- #comment-## -->

  	<?php
  			break;
  	endswitch;
  }
  
  function theme_caption_shortcode($empty, $attr, $content='') {
    
    // Uses code from WordPress under the GPL
    // http://core.trac.wordpress.org/browser/branches/3.4/wp-includes/media.php#L718
    
    extract(shortcode_atts(array(
      'id'    => '',
      'align' => 'alignnone',
      'width' => '',
      'caption' => ''
    ), $attr));
    if ( 1 > (int) $width || empty($caption) ) return $content;
    if ( $id ) $id = 'id="' . esc_attr($id) . '" ';
    return '<div ' . $id . 'class="wp-caption ' . esc_attr($align) . '" style="width: ' . ((int) $width) . 'px">'
    . do_shortcode( $content ) . '<p class="wp-caption-text">' . $caption . '</p></div>';
  }
  
  function theme_excerpt_length() {
    return 55;
  }
  
  function theme_excerpt_more() { global $excerpt_length;
    return '&hellip;';
  }
  
?>